@@ -29,7 +29,10 @@ def _get_column_subquery(seed_table_name, column_strategy):
     elif column_strategy.strategy_type == UpdateColumnStrategyTypes.UNIQUE_LOGIN:
         return f"( SELECT {_RAND_MD5} )"
     elif column_strategy.strategy_type == UpdateColumnStrategyTypes.FAKE_UPDATE:
-        return f"( SELECT `{column_strategy.qualifier}` FROM `{seed_table_name}` ORDER BY RAND() LIMIT 1)"
+        column = f"`{column_strategy.qualifier}`"
+        if column_strategy.sql_type:
+            column = f"CAST({column} AS {column_strategy.sql_type})"
+        return f"( SELECT {column} FROM `{seed_table_name}` ORDER BY RAND() LIMIT 1)"
     elif column_strategy.strategy_type == UpdateColumnStrategyTypes.LITERAL:
         return column_strategy.value
     else:
@@ -50,6 +53,9 @@ def _escape_sql_value(value):
 def get_truncate_table(table_name):
     return f"SET FOREIGN_KEY_CHECKS=0; TRUNCATE TABLE `{table_name}`; SET FOREIGN_KEY_CHECKS=1;"
 
+def get_delete_table(table_name):
+    return f"DELETE FROM `{table_name}`;"
+
 
 def get_create_seed_table(table_name, qualifier_map):
     if len(qualifier_map) < 1:
